/* lora-regular - latin */
@font-face {
	font-family: 'Lora';
	font-style: normal;
	font-weight: 400;
	src: url('/fonts/Lora-Regular.eot'); /* IE9 Compat Modes */
	src: local('Lora'), local('Lora-Regular'),
	   url('/fonts/Lora-Regular.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
	   url('/fonts/Lora-Regular.woff2') format('woff2'), /* Super Modern Browsers */
	   url('/fonts/Lora-Regular.woff') format('woff'), /* Modern Browsers */
	   url('/fonts/Lora-Regular.ttf') format('truetype'); /* Safari, Android, iOS */
}
/* lora-700 - latin */
@font-face {
	font-family: 'Lora';
	font-style: normal;
	font-weight: 700;
	src: url('/fonts/Lora-Bold.eot'); /* IE9 Compat Modes */
	src: local('Lora Bold'), local('Lora-Bold'),
	   url('/fonts/Lora-Bold.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
	   url('/fonts/Lora-Bold.woff2') format('woff2'), /* Super Modern Browsers */
	   url('/fonts/Lora-Bold.woff') format('woff'), /* Modern Browsers */
	   url('/fonts/Lora-Bold.ttf') format('truetype'); /* Safari, Android, iOS */
}
@font-face {
	font-family: 'Lora';
	font-style: italic;
	font-weight: 400;
	src: url('/fonts/Lora-Italic.eot'); /* IE9 Compat Modes */
	src: local('Lora Italic'), local('Lora-Italic'),
	   url('/fonts/Lora-Italic.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
	   url('/fonts/Lora-Italic.woff2') format('woff2'), /* Super Modern Browsers */
	   url('/fonts/Lora-Italic.woff') format('woff'), /* Modern Browsers */
	   url('/fonts/Lora-Italic.ttf') format('truetype'); /* Safari, Android, iOS */
}

