html {
  height: -webkit-fill-available;
  height: -moz-available;
  font-size: 20px;
  /* font-family: Lora, "Palatino Linotype", "Book Antiqua", "New York", "DejaVu serif", serif; */
  font-family: system-ui, -apple-system, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji";
  font-weight: 400;
  text-rendering: optimizeLegibility;
}

body {
  margin: 0;
  height: 100vh;
  /* mobile viewport bug fix */
  min-height: -webkit-fill-available;
  min-height: -moz-available;
}

a, a:visited {
  color: #555;
  border-bottom: 1px dashed #999;
  text-decoration: none;
}

header {
  display: flex;
  align-items: center;
  height: 3em;
  padding: 0 .5em;
  font-size: .9em;
  box-shadow: 1px 3px 3px 0 #bbb;
}

header a {
  color: initial;
  opacity: .8;
  text-decoration: none;
  border-bottom: 0;
}

header .left a {
  display: flex;
  align-items: center;
  color: initial !important;
  opacity: .9;
}

header a:hover {
    opacity: .6;
}

header .title {
  font-family: 'Poppins', sans-serif;
  margin-left: .333em;
}

header .left,
header .right {
  display: inline-flex;
  align-items: center;
  width: 50%;
}

header .right {
  display: inline-flex;
  justify-content: right;
  text-align: right;
  direction: rtl;
  opacity: .8;
}

header .icon {
  background-size: 40px !important;
  width: 40px;
  height: 40px;
  display: inline-flex;
}

header .left .icon {
  width: 2.5em;
  height: 2.5em;
  margin-right: .5em;
}

header .right .icon {
  background: url(/img/rss.png);
}

header .title {
  display: inline-flex;
}

main {
  height: calc(100% - 3em);
  overflow: auto;
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 0 0.25em;
}

h1 {
  font-size: 2em;
  line-height: 1.2em;
}

h2 {
  font-size: 1.5em;
  line-height: 1.1em;
}

h1, h2, h3, h4, h5, h6 {
  font-family: -apple-system, "Segoe UI", Roboto, Oxygen, Ubuntu, Cantarell, "Fira Sans", "Open Sans", "Droid Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
}

footer {
  width: 100%;
  font-size: .65em;
  color: rgba(0, 0, 0, .4);
  letter-spacing: .02em;
  margin-top: .5em;
  padding-top: .25em;
  text-align: center;
  box-shadow: 1px -2px 2px 0 #bbb;
}

.index {
  font-family: -apple-system, "Segoe UI", Roboto, Oxygen, Ubuntu, Cantarell, "Fira Sans", "Open Sans", "Droid Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
}
